Commit 6574cd00763c57cef39ad3d0a9df323904d37864

Edward Thomson 2019-06-08T19:25:36

index: rename `frombuffer` to `from_buffer` The majority of functions are named `from_something` (with an underscore) instead of `fromsomething`. Update the index functions for consistency with the rest of the library.

diff --git a/include/git2/deprecated.h b/include/git2/deprecated.h
index 7c0a6e4..8e0966d 100644
--- a/include/git2/deprecated.h
+++ b/include/git2/deprecated.h
@@ -191,10 +191,11 @@ GIT_EXTERN(void) giterr_set_oom(void);
 
 /**@}*/
 
-/** @name Deprecated Index Constants
+/** @name Deprecated Index Functions and Constants
  *
- * These enumeration values are retained for backward compatibility.
- * The newer versions of these values should be preferred in all new code.
+ * These functions and enumeration values are retained for backward
+ * compatibility.  The newer versions of these values should be
+ * preferred in all new code.
  *
  * There is no plan to remove these backward compatibility values at
  * this time.
@@ -234,6 +235,11 @@ GIT_EXTERN(void) giterr_set_oom(void);
 #define GIT_INDEXCAP_NO_SYMLINKS       GIT_INDEX_CAPABILITY_NO_SYMLINKS
 #define GIT_INDEXCAP_FROM_OWNER        GIT_INDEX_CAPABILITY_FROM_OWNER
 
+GIT_EXTERN(int) git_index_add_frombuffer(
+	git_index *index,
+	const git_index_entry *entry,
+	const void *buffer, size_t len);
+
 /**@}*/
 
 /** @name Deprecated Object Constants
diff --git a/include/git2/index.h b/include/git2/index.h
index fce3616..8723aa6 100644
--- a/include/git2/index.h
+++ b/include/git2/index.h
@@ -572,7 +572,7 @@ GIT_EXTERN(int) git_index_add_bypath(git_index *index, const char *path);
  * @param len length of the data
  * @return 0 or an error code
  */
-GIT_EXTERN(int) git_index_add_frombuffer(
+GIT_EXTERN(int) git_index_add_from_buffer(
 	git_index *index,
 	const git_index_entry *entry,
 	const void *buffer, size_t len);
diff --git a/src/index.c b/src/index.c
index ec43433..482728d 100644
--- a/src/index.c
+++ b/src/index.c
@@ -1454,7 +1454,7 @@ GIT_INLINE(bool) valid_filemode(const int filemode)
 	return (is_file_or_link(filemode) || filemode == GIT_FILEMODE_COMMIT);
 }
 
-int git_index_add_frombuffer(
+int git_index_add_from_buffer(
     git_index *index, const git_index_entry *source_entry,
     const void *buffer, size_t len)
 {
@@ -3709,3 +3709,12 @@ void git_indexwriter_cleanup(git_indexwriter *writer)
 	git_index_free(writer->index);
 	writer->index = NULL;
 }
+
+/* Deprecated functions */
+
+int git_index_add_frombuffer(
+    git_index *index, const git_index_entry *source_entry,
+    const void *buffer, size_t len)
+{
+	return git_index_add_from_buffer(index, source_entry, buffer, len);
+}
diff --git a/tests/index/racy.c b/tests/index/racy.c
index 88b37e1..b06f55d 100644
--- a/tests/index/racy.c
+++ b/tests/index/racy.c
@@ -193,7 +193,7 @@ static void setup_uptodate_files(void)
 	/* Put 'C' into the index */
 	new_entry.path = "C";
 	new_entry.mode = GIT_FILEMODE_BLOB;
-	cl_git_pass(git_index_add_frombuffer(index, &new_entry, "hello!\n", 7));
+	cl_git_pass(git_index_add_from_buffer(index, &new_entry, "hello!\n", 7));
 
 	git_index_free(index);
 	git_buf_dispose(&path);
diff --git a/tests/index/tests.c b/tests/index/tests.c
index 7c29ef3..2d2744d 100644
--- a/tests/index/tests.c
+++ b/tests/index/tests.c
@@ -310,7 +310,7 @@ void test_index_tests__add_frombuffer(void)
 	memset(&entry, 0x0, sizeof(git_index_entry));
 	entry.mode = GIT_FILEMODE_BLOB;
 	entry.path = "test.txt";
-	cl_git_pass(git_index_add_frombuffer(index, &entry,
+	cl_git_pass(git_index_add_from_buffer(index, &entry,
 		content, strlen(content)));
 
 	/* Wow... it worked! */
@@ -352,7 +352,7 @@ void test_index_tests__dirty_and_clean(void)
 	/* Index is dirty after adding an entry */
 	entry.mode = GIT_FILEMODE_BLOB;
 	entry.path = "test.txt";
-	cl_git_pass(git_index_add_frombuffer(index, &entry, "Hi.\n", 4));
+	cl_git_pass(git_index_add_from_buffer(index, &entry, "Hi.\n", 4));
 	cl_assert(git_index_entrycount(index) == 1);
 	cl_assert(git_index_is_dirty(index));
 
@@ -374,7 +374,7 @@ void test_index_tests__dirty_and_clean(void)
 	cl_assert(!git_index_is_dirty(index));
 
 	/* Index is dirty when we do an unforced read with dirty content */
-	cl_git_pass(git_index_add_frombuffer(index, &entry, "Hi.\n", 4));
+	cl_git_pass(git_index_add_from_buffer(index, &entry, "Hi.\n", 4));
 	cl_assert(git_index_entrycount(index) == 1);
 	cl_assert(git_index_is_dirty(index));
 
@@ -402,7 +402,7 @@ void test_index_tests__dirty_fails_optionally(void)
 	/* Index is dirty after adding an entry */
 	entry.mode = GIT_FILEMODE_BLOB;
 	entry.path = "test.txt";
-	cl_git_pass(git_index_add_frombuffer(index, &entry, "Hi.\n", 4));
+	cl_git_pass(git_index_add_from_buffer(index, &entry, "Hi.\n", 4));
 	cl_assert(git_index_is_dirty(index));
 
 	cl_git_pass(git_checkout_head(repo, NULL));
@@ -410,7 +410,7 @@ void test_index_tests__dirty_fails_optionally(void)
 	/* Index is dirty (again) after adding an entry */
 	entry.mode = GIT_FILEMODE_BLOB;
 	entry.path = "test.txt";
-	cl_git_pass(git_index_add_frombuffer(index, &entry, "Hi.\n", 4));
+	cl_git_pass(git_index_add_from_buffer(index, &entry, "Hi.\n", 4));
 	cl_assert(git_index_is_dirty(index));
 
 	cl_git_pass(git_libgit2_opts(GIT_OPT_ENABLE_UNSAVED_INDEX_SAFETY, 1));
@@ -455,7 +455,7 @@ void test_index_tests__add_frombuffer_reset_entry(void)
 	memset(&entry, 0x0, sizeof(git_index_entry));
 	entry.mode = GIT_FILEMODE_BLOB;
 	entry.path = "test.txt";
-	cl_git_pass(git_index_add_frombuffer(index, &entry,
+	cl_git_pass(git_index_add_from_buffer(index, &entry,
 		content, strlen(content)));
 
 	/* Wow... it worked! */
diff --git a/tests/index/version.c b/tests/index/version.c
index 7ada302..3827df8 100644
--- a/tests/index/version.c
+++ b/tests/index/version.c
@@ -55,7 +55,7 @@ void test_index_version__can_write_v4(void)
 		memset(&entry, 0, sizeof(entry));
 		entry.path = paths[i];
 		entry.mode = GIT_FILEMODE_BLOB;
-		cl_git_pass(git_index_add_frombuffer(index, &entry, paths[i],
+		cl_git_pass(git_index_add_from_buffer(index, &entry, paths[i],
 						     strlen(paths[i]) + 1));
 	}
 	cl_assert_equal_sz(git_index_entrycount(index), ARRAY_SIZE(paths));
@@ -100,7 +100,7 @@ void test_index_version__v4_uses_path_compression(void)
 			path[ARRAY_SIZE(path) - 3] = i;
 			path[ARRAY_SIZE(path) - 2] = j;
 			path[ARRAY_SIZE(path) - 1] = '\0';
-			cl_git_pass(git_index_add_frombuffer(index, &entry, buf, sizeof(buf)));
+			cl_git_pass(git_index_add_from_buffer(index, &entry, buf, sizeof(buf)));
 		}
 	}
 
diff --git a/tests/object/tree/read.c b/tests/object/tree/read.c
index a20ec38..4c4636b 100644
--- a/tests/object/tree/read.c
+++ b/tests/object/tree/read.c
@@ -98,7 +98,7 @@ void test_object_tree_read__largefile(void)
 	ie.path = BIGFILE;
 
 	cl_git_pass(git_repository_index(&index, g_repo));
-	cl_git_pass(git_index_add_frombuffer(index, &ie, buf, BIGFILE_SIZE));
+	cl_git_pass(git_index_add_from_buffer(index, &ie, buf, BIGFILE_SIZE));
 	cl_repo_commit_from_index(&oid, g_repo, NULL, 0, BIGFILE);
 
 	cl_git_pass(git_commit_lookup(&commit, g_repo, &oid));
diff --git a/tests/index/filemodes.c b/tests/index/filemodes.c
index f2ca456..af1f803 100644
--- a/tests/index/filemodes.c
+++ b/tests/index/filemodes.c
@@ -164,7 +164,7 @@ static void add_entry_and_check_mode_(
 	git_index_entry new_entry;
 
 	/* If old_filename exists, we copy that to the new file, and test
 	 * git_index_add(), otherwise create a new entry testing git_index_add_frombuffer
 	 */
 	if (from_file)
 	{
@@ -189,7 +189,7 @@ static void add_entry_and_check_mode_(
 	else
 	{
 		const char *content = "hey there\n";
-		clar__assert(!git_index_add_frombuffer(index, &new_entry, content, strlen(content)),
+		clar__assert(!git_index_add_from_buffer(index, &new_entry, content, strlen(content)),
 			file, line, "Cannot add index entry from buffer", NULL, 1);
 	}
 
@@ -207,7 +207,7 @@ void test_index_filemodes__explicit(void)
 	git_index *index;
 
 	/* These tests should run and work everywhere, as the filemode is
 	 * given explicitly to git_index_add or git_index_add_frombuffer
 	 */
 	cl_repo_set_bool(g_repo, "core.filemode", false);
 
@@ -271,7 +271,7 @@ void test_index_filemodes__frombuffer_requires_files(void)
 	new_entry.path = "dummy-file.txt";
 	new_entry.mode = GIT_FILEMODE_BLOB;
 
-	cl_git_pass(git_index_add_frombuffer(index,
+	cl_git_pass(git_index_add_from_buffer(index,
 		&new_entry, content, strlen(content)));
 
 	cl_assert((ret_entry = git_index_get_bypath(index, "dummy-file.txt", 0)));
@@ -282,7 +282,7 @@ void test_index_filemodes__frombuffer_requires_files(void)
 	new_entry.path = "dummy-file.txt";
 	new_entry.mode = GIT_FILEMODE_BLOB_EXECUTABLE;
 
-	cl_git_pass(git_index_add_frombuffer(index,
+	cl_git_pass(git_index_add_from_buffer(index,
 		&new_entry, content, strlen(content)));
 
 	cl_assert((ret_entry = git_index_get_bypath(index, "dummy-file.txt", 0)));
@@ -293,7 +293,7 @@ void test_index_filemodes__frombuffer_requires_files(void)
 	new_entry.path = "dummy-link.txt";
 	new_entry.mode = GIT_FILEMODE_LINK;
 
-	cl_git_pass(git_index_add_frombuffer(index,
+	cl_git_pass(git_index_add_from_buffer(index,
 		&new_entry, content, strlen(content)));
 
 	cl_assert((ret_entry = git_index_get_bypath(index, "dummy-link.txt", 0)));
@@ -304,7 +304,7 @@ void test_index_filemodes__frombuffer_requires_files(void)
 	new_entry.path = "invalid_mode.txt";
 	new_entry.mode = GIT_FILEMODE_TREE;
 
-	cl_git_fail(git_index_add_frombuffer(index,
+	cl_git_fail(git_index_add_from_buffer(index,
 		&new_entry, content, strlen(content)));
 	cl_assert_equal_p(NULL, git_index_get_bypath(index, "invalid_mode.txt", 0));
 
@@ -312,7 +312,7 @@ void test_index_filemodes__frombuffer_requires_files(void)
 	new_entry.path = "invalid_mode.txt";
 	new_entry.mode = GIT_FILEMODE_COMMIT;
 
-	cl_git_fail(git_index_add_frombuffer(index,
+	cl_git_fail(git_index_add_from_buffer(index,
 		&new_entry, content, strlen(content)));
 	cl_assert_equal_p(NULL, git_index_get_bypath(index, "invalid_mode.txt", 0));
 
@@ -164,7 +164,7 @@ static void add_entry_and_check_mode_(
 
 	/* If old_filename exists, we copy that to the new file, and test
-	 * git_index_add(), otherwise create a new entry testing git_index_add_frombuffer
+	 * git_index_add(), otherwise create a new entry testing git_index_add_from_buffer
 	 */
 	if (from_file)
@@ -207,7 +207,7 @@ void test_index_filemodes__explicit(void)
 
 	/* These tests should run and work everywhere, as the filemode is
-	 * given explicitly to git_index_add or git_index_add_frombuffer
+	 * given explicitly to git_index_add or git_index_add_from_buffer
 	 */
 	cl_repo_set_bool(g_repo, "core.filemode", false);